<?php

namespace Drupal\mcapi_forms;
use Drupal\mcapi\Entity\WalletInterface;
use Drupal\mcapi_forms\Entity\McForm;
use Drupal\mcapi\Entity\Type;

class McFormFunctions {

  /**
   * Create links to the payment forms, prepopulated if possible.
   *
   * Iterate through the transaction form displays and create links to ones using
   * the 'my_wallet' widget.
   *
   * @param WalletInterface $wallet
   *
   * @return array[]
   *   Items each containing a Url and string value
   */
  static function quickLinks(WalletInterface $wallet) : array {
    $links = [];
    $ids = \Drupal::entityTypeManager()->getStorage('entity_form_display')->getQuery()->accessCheck(FALSE)
      ->condition('id', 'mc_transaction.mc_transaction.default', '<>')
      ->condition('bundle', 'mc_transaction')
      ->execute();
    foreach (McForm::loadMultiple() as $id => $mc_form) {
      $workflow = Type::load($mc_form->workflow_type);

      $options = [];
      if ($workflow->direction == 'bill') {
        $options['query'] = ['payer' => $wallet->id()];
      }
      else {
        $options['query'] = ['payee' => $wallet->id()];
      }

      $links[$id] = [
        'title' => str_replace('[mc_wallet:name]', $wallet->label(), $mc_form->wallet_link_title),
        'url' => Url::fromUserInput($mc_form->path, $options)
      ];
    }

    return $info;
  }

  /**
   * Migration helper.
   * Get only the translated field names used in the template.
   *
   * @param string $template
   * @param string $dir
   *   outgoing, incoming or 3rdparty
   *
   * @return array
   *   The field names used in the templated, mapped to the modern names.
   */
   static function MigrateTemplateFieldMap($template) : array {
    //Get the tokens used in the old template
    preg_match_all('/\[mcapiform:([a-z_]+)\]/', $template, $matches);
    $old_tokens = $matches[1];
    unset($old_tokens[array_search('direction', $old_tokens)]);

    $mapping = [
      "payee" => "payee",
      "payer" => "payer",
      //"offers_wants_categories" => "category", // assumes smallads has upgraded & renamed the vocab..
      "transaction_description" => "description"
    ] + array_combine($old_tokens, $old_tokens);

    return $mapping;

  }

}
