<?php

namespace Drupal\mcapi_forms\Plugin\Derivative;

use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Component\Plugin\Derivative\DeriverBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManager;

/**
 * Provides local actions to create smallads of each type.
 */
class TransactionFormTasks extends DeriverBase implements ContainerDeriverInterface {

  /**
   * @var array
   */
  protected $forms;

  /**
   * {@inheritDoc}
   */
  public function __construct(EntityTypeManager $entity_type_manager) {
    $this->forms = $entity_type_manager->getStorage('mc_form')->loadMultiple();
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritDoc}
   * Make a default tab for the main views
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    // Put the forms in order of the menu weight
    usort(
      $this->forms,
      function ($a, $b){return $a->menu['weight'] <=> $b->menu['weight'];}
    );
    $tabs = [];
    $w=0;
    foreach ($this->forms as $mc_form) {
      if (!empty($mc_form->hasTransactionTab())) {
        $this->derivatives['mcapi_forms.tabs.'.$mc_form->id()] = [
          'title' => $mc_form->menu['title'],
          'description' => '',
          'route_name' => 'mcapi_forms.add_transaction',
          'route_parameters' => ['mc_form' => $mc_form->id()],
          'base_route' => 'entity.mc_transaction.add_form',
          'weight' => $w++,
        ] + $base_plugin_definition;
      }
    }
    return $this->derivatives;
  }

}
