<?php

namespace Drupal\mcapi_limits\Plugin\Limits;

use Drupal\mcapi\Entity\WalletInterface;
use Drupal\mcapi_limits\Plugin\McapiLimitsBase;
use \Drupal\Core\Form\FormStateInterface;
/**
 * No balance limits.
 *
 * @Limits(
 *   id = "balanced",
 *   label = @Translation("Balanced"),
 *   description = @Translation("Limits are the same distance from zero")
 * )
 */
class Balanced extends McapiLimitsBase {

  /**
   * {@inheritDoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    return[
      'liquidity' => [
        '#title' => $this->t('Liquidity per user'),
        '#description' => $this->t('The distance from zero a user can trade'),
        '#type' => 'worth',
        '#default_value' => $this->configuration['liquidity'],
        '#min' => 0
      ]
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function getLimits(WalletInterface $wallet) {
    $limit = $this->configuration['liquidity'] ?? NULL;
    return [
      'min' => -$limit,
      'max' => $limit,
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function defaultConfiguration() {
    $defaults = parent::defaultConfiguration();
    $defaults['liquidity'] = 1000;
    return $defaults;
  }



  /**
   * {@inheritdoc}
   */
  public function storageSettingsForm(array &$form, FormStateInterface $form_state, $has_data) {
    return [];
  }
}
