<?php

namespace Drupal\mcapi\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Build form to edit, workflow config entity
 */
class WorkflowEdit extends EntityForm {

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'mcapi_workflow_form';
  }

  /**
   * {@inheritDoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $form['#title'] = $this->t("Editing '@name' workflow", ['@name' => $this->entity->label]);

    // Need to unset the id?
    $form['editable'] = [
      '#title' => $this->t('Workflow type definition'),
      '#description' => $this->t('Must be valid javascript. @todo make a json schema and validate against it.'),
      '#type' => 'textarea',
      '#rows' => 20,
      '#default_value' => json_encode($this->entity, JSON_PRETTY_PRINT),
      '#element_validate' => [[$this, 'JsValidate']]
    ];
    return $form;
  }

  /**
   * {@inheritDoc}
   */
  function buildEntity($form, $form_state) {
    $values = json_decode($form_state->getValue('editable'), JSON_OBJECT_AS_ARRAY);
    $entity = clone($this->entity);
    foreach ($values as $key => $value) {
      $entity->set($key, $value);
    }
    return $entity;
  }

  function validateForm(array &$form, FormStateInterface $form_state) {
    // no validation at the moment beyond creating the endity.

  }

  /**
   * {@inheritDoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    parent::save($form, $form_state);
    $form_state->setRedirect('mcapi.admin');
  }

  public function jsValidate(&$element, $form_state) {
    $input = $element['#value'];
    if (!json_decode($input)) {
      $form_state->setError($element, $this->t('Not a valid javascript object.'));
    }
  }

}
