<?php

namespace Drupal\mcapi\Plugin\Derivative;

use Drupal\mcapi\Functions;
use Drupal\mcapi\Entity\Type as McType;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Component\Plugin\Derivative\DeriverBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Local action definitions to create a wallet for each entity types configured.
 */
class TransactionLocalAction extends DeriverBase implements ContainerDeriverInterface {
  use StringTranslationTrait;

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static();
  }

  /**
   * {@inheritDoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    foreach (McType::loadMultiple() as $type) {
      $key = "mcapi.transaction.add.{$type->id}.action";
      $this->derivatives[$key] = [
        'title' => t("@type transaction", ['@type' => $type->label]),
        'options' => ['attributes' => ['title' => $type->summary]],
        'id' => "mcapi.wallet.add.{$type->id}.action",
        'route_name' => "entity.mc_transaction.add_form",
        'route_parameters' => [
          'mc_type' => $type->id
        ],
        'appears_on' => [
          'mcapi.admin',
          //'entity.mc_transaction.collection'
        ]
      ] + $base_plugin_definition;
    }
    return $this->derivatives;
  }

}
